From 5250162b129288b78bfead87aa99a9639a8a9280 Mon Sep 17 00:00:00 2001
From: Matt Wala <wala1@illinois.edu>
Date: Sat, 8 Apr 2017 15:50:41 -0500
Subject: [PATCH] Allow function calls as args to tuple typed reductions.

---
 loopy/symbolic.py | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/loopy/symbolic.py b/loopy/symbolic.py
index 44be6f9c9..0d8543270 100644
--- a/loopy/symbolic.py
+++ b/loopy/symbolic.py
@@ -450,7 +450,7 @@ class Reduction(p.Expression):
         type, it must be one of the following:
          * a :class:`tuple` of :class:`pymbolic.primitives.Expression`, or
          * a :class:`loopy.symbolic.Reduction`, or
          * a substitution rule invocation.
 
     .. attribute:: allow_simultaneous
 
@@ -492,8 +492,8 @@ class Reduction(p.Expression):
 
             if not isinstance(expr, (tuple, Reduction, Call)):
                 raise LoopyError("reduction argument must be one of "
-                                 "a tuple, reduction, or substitution rule "
-                                 "invocation, got '%s'" % type(expr).__name__)
+                                 "a tuple, reduction, or call; "
+                                 "got '%s'" % type(expr).__name__)
         else:
             # Sanity checks
             if isinstance(expr, tuple):
@@ -450,7 +450,7 @@ class Reduction(p.Expression):
          * a :class:`tuple` of :class:`pymbolic.primitives.Expression`, or
          * a :class:`loopy.symbolic.Reduction`, or
-         * a substitution rule invocation.
+         * a function call or substitution rule invocation.
 
     .. attribute:: allow_simultaneous
-- 
GitLab